windows: Rename reset_all_windows to windows_reset_all

Change-Id: Ibcbfa51e83a678fb1eddeeebfb22dd870bb112da
Signed-off-by: Andrew Jeffery <andrew@aj.id.au>
diff --git a/windows.c b/windows.c
index 729a4d3..3759bb3 100644
--- a/windows.c
+++ b/windows.c
@@ -423,11 +423,11 @@
 }
 
 /*
  * reset_all_windows() - Reset all windows to a well defined default state
  * @context:		The mbox context pointer
  * @set_bmc_event:	If any state change should be indicated to the host
  */
-void reset_all_windows(struct mbox_context *context, bool set_bmc_event)
+void windows_reset_all(struct mbox_context *context, bool set_bmc_event)
 {
 	int i;
@@ -423,11 +423,11 @@
 
 /*
- * reset_all_windows() - Reset all windows to a well defined default state
+ * windows_reset_all() - Reset all windows to a well defined default state
  * @context:		The mbox context pointer
  * @set_bmc_event:	If any state change should be indicated to the host